"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.renewAccessToken = exports.changeCodeForTokens = void 0;
const utils_1 = require("@procyon/utils");
const slice_1 = require("./slice");
const changeCodeForTokens = ({ baseUrl, tokenEndpoint, clientId, code, redirectUri, }) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const response = yield fetch(`${baseUrl}${tokenEndpoint}`, {
            method: 'post',
            headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
            body: new URLSearchParams({
                code,
                client_id: clientId,
                grant_type: 'authorization_code',
                redirect_uri: redirectUri,
            }),
        });
        const data = yield response
            .text()
            .then((text) => ((0, utils_1.isJSON)(text) ? JSON.parse(text) : text));
        if (!response.ok)
            throw response;
        return { data };
    }
    catch (error) {
        return { error };
    }
});
exports.changeCodeForTokens = changeCodeForTokens;
const renewAccessToken = ({ baseUrl, clientId, tokenEndpoint, refreshToken }, api) => __awaiter(void 0, void 0, void 0, function* () {
    const response = yield fetch(`${baseUrl}${tokenEndpoint}`, {
        method: 'post',
        headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
        body: new URLSearchParams({
            client_id: clientId,
            grant_type: 'refresh_token',
            refresh_token: refreshToken,
        }),
    });
    const data = yield response
        .text()
        .then((text) => ((0, utils_1.isJSON)(text) ? JSON.parse(text) : text));
    if (!response.ok)
        throw response;
    api.dispatch((0, slice_1.setAuthAttributes)({
        accessToken: data.access_token,
        refreshToken: data.refresh_token,
        idToken: data.id_token,
        accessExpiresIn: data.expires_in,
        refreshExpiresIn: data.refresh_expires_in,
        sessionState: data.session_state,
    }));
});
exports.renewAccessToken = renewAccessToken;
